@@ -17,12 +17,11 @@ from satnogsdbapiclient.model.mode import Mode
 from satnogsdbapiclient.model.new_artifact import NewArtifact
 from satnogsdbapiclient.model.paginated_artifact_list import PaginatedArtifactList
 from satnogsdbapiclient.model.paginated_telemetry_list import PaginatedTelemetryList
-from satnogsdbapiclient.model.sat_telemetry import SatTelemetry
 from satnogsdbapiclient.model.satellite import Satellite
-from satnogsdbapiclient.model.satellite_status_enum import SatelliteStatusEnum
 from satnogsdbapiclient.model.service_enum import ServiceEnum
+from satnogsdbapiclient.model.status_enum import StatusEnum
 from satnogsdbapiclient.model.telemetry import Telemetry
 from satnogsdbapiclient.model.telemetry_request import TelemetryRequest
 from satnogsdbapiclient.model.transmitter import Transmitter
-from satnogsdbapiclient.model.transmitter_status_enum import TransmitterStatusEnum
+from satnogsdbapiclient.model.transmitter_request import TransmitterRequest
 from satnogsdbapiclient.model.type_enum import TypeEnum
